import re
import random

class Processor:

    def correct_case(self, text):
        # lower case
        text = text.lower()
        # upper case exception
        text = re.sub("(^|[^\w])i([^\w]|$)", r"\1I\2", text)
        return text

    def trim_spaces(self, text):
        # chop leading spaces
        text = re.sub("^ +", "", text)
        # chop trailing spaces
        text = re.sub(" +$", "", text)
        return text

    def trim_trailing_full_stop(self, text):
        # drop trailing full stops
        # but not if there's more than one full stop
        text = re.sub("([^.])\.$", r"\1", text)
        return text

    def replace_curly_quotes(self, text):
        text = re.sub("“", "\"", text)
        text = re.sub("”", "\"", text)
        text = re.sub("‘", "'", text)
        text = re.sub("’", "'", text)
        return text

    def expand_elipsis(self, text):
        text = re.sub("…", "...", text)
        return text

    def strip_usernames(self, text):
        # don't mention people
        text = re.sub("@\w+", "@irlnomi", text)
        return text

    def run(self, text):
        # text = self.correct_case(text)
        text = self.trim_spaces(text)
        text = self.trim_trailing_full_stop(text)
        text = self.replace_curly_quotes(text)
        text = self.expand_elipsis(text)
        text = self.strip_usernames(text)
        return text



import os
import imp

import setuptools

PACKAGE = "mimicbot"
DESCRIPTION = "A Twitter mimic bot"

pwd = os.path.join(os.path.dirname(__file__))
filename= os.path.join(pwd, "src", PACKAGE, "__init__.py")
version = imp.load_source(PACKAGE, filename).__version__

setuptools.setup(
    name=PACKAGE,
    version=version,
    description=DESCRIPTION,
    classifiers=[
        "Development Status :: 1 - Planning",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Topic :: Artistic Software"
    ],
    author="Naomi Slater",
    author_email="nslater@tumbolia.org",
    url="https://github.com/nslater/mimicbot",
    keywords="twitter bot",
    license="Apache License 2.0",
    packages=setuptools.find_packages("src"),
    package_dir={"": "src"},
    entry_points = {
        "console_scripts": ["mimicbot=mimicbot.cli:cli"],
    },
    test_suite="nose2.collector.collector",
    install_requires=[
      "setuptools",
      "MarkovText",
      "twitter",
      "pyparsing",
      "click"
    ]
)
